@@ -88,10 +88,15 @@ class Conversions:
 
     def utc_from_mbtime(self, timestamp: str) -> dt.datetime:
         """Return UTC time from a Metobridge timestamp."""
-        if timestamp is None:
+        if timestamp is None or len(timestamp) == 0:
+            return None
+
+        try:
+            dt_obj = dt.datetime.strptime(timestamp, "%Y%m%d%H%M%S")
+            return dt_obj.replace(tzinfo=UTC)
+        except Exception as e:
+            _LOGGER.error("An error occured converting MB Time. Input Value is : %s and Error message is %s", timestamp, str(e))
             return None
-        dt_obj = dt.datetime.strptime(timestamp, "%Y%m%d%H%M%S")
-        return dt_obj.replace(tzinfo=UTC)
 
     def hw_platform(self, platform: str) -> str:
         """Return the meteobridge HW Platform."""
